==> react-lazy-hydration-0.0.1.tgz: package/es/hook.js <==
import React, { useLayoutEffect, useRef, useState } from "react";
export function useLazyHydration(component, props) {
  var ssrOnly = props.ssrOnly,
      whenIdle = props.whenIdle,
      whenVisible = props.whenVisible;

  if (!ssrOnly && !whenIdle && !whenVisible) {
    console.warn("LazyHydrate: Set atleast one of the props to 'true'");
  }

  var _useState = useState(typeof window === "undefined"),
      hydrated = _useState[0],
      setHydrated = _useState[1];

  var childRef = useRef(null);
  var cleanupFns = useRef([]);

  function cleanup() {
    while (cleanupFns.current.length > 0) {
      cleanupFns.current.pop()();
    }
  }

  function hydrate() {
    setHydrated(true);
    cleanup();
  }

  var io = typeof IntersectionObserver !== "undefined" ? new IntersectionObserver(function (entries) {
    entries.forEach(function (entry) {
      if (entry.target.parentElement === childRef.current && (entry.isIntersecting || entry.intersectionRatio > 0)) {
        hydrate();
      }
    });
  }) : null;
  useLayoutEffect(function () {
    if (childRef.current.childElementCount === 0) {
      // No SSR rendered content.
      hydrate();
      return;
    }

    if (ssrOnly) return;

    if (whenIdle) {
      // @ts-ignore
      if (window.requestIdleCallback) {
        // @ts-ignore
        var id = window.requestIdleCallback(function () {
          return requestAnimationFrame(function () {
            return hydrate();
          });
        }, {
          timeout: 500
        }); // @ts-ignore

        cleanupFns.current.push(function () {
          return cancelIdleCallback(id);
        });
      } else {
        hydrate();
        return;
      }
    }

    if (whenVisible) {
      if (io) {
        io.observe(childRef.current.children[0]);
        cleanupFns.current.push(function () {
          return io.unobserve(childRef.current.children[0]);
        });
      } else {
        hydrate();
      }
    }

    return cleanup;
  }, []);

  if (hydrated) {
    return React.createElement("div", {
      ref: childRef,
      style: {
        display: "contents"
      }
    }, component);
  } else {
    return React.createElement("div", {
      ref: childRef,
      style: {
        display: "contents"
      },
      dangerouslySetInnerHTML: {
        __html: ""
      }
    });
  }
}

==> react-lazy-hydration-0.0.2.tgz: package/es/hook.js <==
import React, { useLayoutEffect, useRef, useState } from "react";
export function useLazyHydration(component, props) {
  var ssrOnly = props.ssrOnly,
      whenIdle = props.whenIdle,
      whenVisible = props.whenVisible;

  if (!ssrOnly && !whenIdle && !whenVisible) {
    console.warn("LazyHydrate: Set atleast one of the props to 'true'");
  }

  var _useState = useState(typeof window === "undefined"),
      hydrated = _useState[0],
      setHydrated = _useState[1];

  var childRef = useRef(null);
  var cleanupFns = useRef([]);

  function cleanup() {
    while (cleanupFns.current.length > 0) {
      cleanupFns.current.pop()();
    }
  }

  function hydrate() {
    setHydrated(true);
    cleanup();
  }

  var io = useRef(null);
  useLayoutEffect(function () {
    if (childRef.current.childElementCount === 0) {
      // No SSR rendered content.
      hydrate();
      return;
    }

    if (ssrOnly) return;

    if (whenIdle) {
      // @ts-ignore
      if (window.requestIdleCallback) {
        // @ts-ignore
        var id = window.requestIdleCallback(function () {
          return requestAnimationFrame(function () {
            return hydrate();
          });
        }, {
          timeout: 500
        }); // @ts-ignore

        cleanupFns.current.push(function () {
          return cancelIdleCallback(id);
        });
      } else {
        hydrate();
        return;
      }
    }

    if (whenVisible) {
      if (typeof IntersectionObserver !== "undefined") {
        io.current = new IntersectionObserver(function (entries) {
          entries.forEach(function (entry) {
            if (entry.target.parentElement === childRef.current && (entry.isIntersecting || entry.intersectionRatio > 0)) {
              hydrate();
            }
          });
        });
        io.current.observe(childRef.current.children[0]);
        cleanupFns.current.push(function () {
          return io.current.unobserve(childRef.current.children[0]);
        });
      } else {
        hydrate();
      }
    }

    return cleanup;
  }, []);
  var lazyComponent = hydrated ? React.createElement("div", {
    ref: childRef,
    style: {
      display: "contents"
    }
  }, component) : React.createElement("div", {
    ref: childRef,
    style: {
      display: "contents"
    },
    dangerouslySetInnerHTML: {
      __html: ""
    }
  });
  return [lazyComponent, hydrated];
}
